@@ -14,7 +14,7 @@ from oauth2client.service_account import ServiceAccountCredentials
 
 class EasySpreadsheet():
     
-    def __init__(self, auth_json: dict, spreadsheet_id: str, sheet_name: str):
+    def __init__(self, auth_json: dict, spreadsheet_id: str, sheet_name: str, load=True):
 
 
         self.table = None
@@ -24,8 +24,8 @@ class EasySpreadsheet():
         self._doc = self._get_doc(auth_json, spreadsheet_id)
         self._sheet_name = sheet_name
         self._cloudsheet= None
-
-        self._load()
+        if load:
+            self._load()
     
     def select(self):
         return self.table
